#!moo verb news --on $player

# pylint: disable=return-outside-function,undefined-variable

"""
This is a very simple verb used as a player command to print out the current MOO news. It makes a simple call to the
verb `$news:read` to actually perform the reading task.
"""

print("news is not yet implemented.")
