"""
The letter class is a subclass of the note class. A letter object provides all of the functions of a note, with the
addition of a `burn` command. This command will recycle the note after it has been read by the recipient, completely
removing it from the database. The letter is read, written, erased and encrypted just as if it were simply a note
object.
"""
