#!moo verb title --on $root_class

# pylint: disable=return-outside-function,undefined-variable

"""
Get the name property of this object.

One example where it might be useful to redefine this verb is if you want to add an honorificor descriptive phrase to
the end of your name. By overriding the `title` verb, you can append anything you like to the `name` property of the
object.
"""

if not this.name:
    return str(this)
return this.name
